==> alfred-ui-native-components-0.0.90.tgz: package/ui/atoms/switch/switch/index.tsx <==
import React, { FC } from 'react';
import { Switch as SwitchNative } from 'react-native-switch';
import { SpinnerIcon } from '../../icons/spinner';
import { defaultTrackColor, SizeOption, styles } from './styles';

export const sizeTypes: {
  SMALL: SizeOption;
  MEDIUM: SizeOption;
  LARGE: SizeOption;
} = {
  SMALL: 'SMALL',
  MEDIUM: 'MEDIUM',
  LARGE: 'LARGE',
};

export interface SwitchProps {
  disabled?: boolean;
  loading?: boolean;
  onValueChange?: (value: boolean) => void;
  value?: boolean;
  testID?: string
}

interface SizeProps {
  size?: SizeOption;
}

interface Props extends SwitchProps, SizeProps { }

export const Switch: FC<Props> = ({
  disabled = false,
  loading = false,
  onValueChange,
  value = false,
  size = sizeTypes.MEDIUM,
  testID,
}) => {
  const Styles = styles({ value, disabled, size });

  return (
    <SwitchNative
      activeText={undefined}
      backgroundActive={defaultTrackColor.true}
      backgroundInactive={defaultTrackColor.false}
      changeValueImmediately={undefined}
      circleActiveColor={undefined}
      circleBorderWidth={0}
      circleInActiveColor={undefined}
      disabled={disabled}
      inActiveText={undefined}
      innerCircleStyle={Styles.innerCircleStyle}
      onValueChange={onValueChange}
      outerCircleStyle={undefined}
      renderActiveText={false}
      renderInActiveText={false}
      renderInsideCircle={() => loading && <SpinnerIcon />}
      switchBorderRadius={undefined}
      switchLeftPx={3}
      switchRightPx={3}
      switchWidthMultiplier={1.7}
      value={value}
      containerStyle={Styles.containerStyle}
      testID={testID}
    />
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/atoms/switch/switch/index.tsx <==
import React, { FC } from 'react';
import { Switch as SwitchNative } from 'react-native-switch';
import { SpinnerIcon } from '../../icons';
import { defaultTrackColor, SizeOption, styles } from './styles';

export const sizeTypes: {
  SMALL: SizeOption;
  MEDIUM: SizeOption;
  LARGE: SizeOption;
} = {
  SMALL: 'SMALL',
  MEDIUM: 'MEDIUM',
  LARGE: 'LARGE',
};

export interface SwitchProps {
  disabled?: boolean;
  loading?: boolean;
  onValueChange?: (value: boolean) => void;
  value?: boolean;
  testID?: string
}

interface SizeProps {
  size?: SizeOption;
}

interface Props extends SwitchProps, SizeProps { }

export const Switch: FC<Props> = ({
  disabled = false,
  loading = false,
  onValueChange,
  value = false,
  size = sizeTypes.MEDIUM,
  testID,
}) => {
  const Styles = styles({ value, disabled, size });

  return (
    <SwitchNative
      activeText={undefined}
      backgroundActive={defaultTrackColor().true}
      backgroundInactive={defaultTrackColor().false}
      changeValueImmediately={undefined}
      circleActiveColor={undefined}
      circleBorderWidth={0}
      circleInActiveColor={undefined}
      disabled={disabled}
      inActiveText={undefined}
      innerCircleStyle={Styles.innerCircleStyle}
      onValueChange={onValueChange}
      outerCircleStyle={undefined}
      renderActiveText={false}
      renderInActiveText={false}
      renderInsideCircle={() => loading && <SpinnerIcon />}
      switchBorderRadius={undefined}
      switchLeftPx={3}
      switchRightPx={3}
      switchWidthMultiplier={1.7}
      value={value}
      containerStyle={Styles.containerStyle}
      testID={testID}
    />
  );
};
